@@ -384,7 +384,6 @@ greeter_ctrl_handler (GIOChannel *source,
 	buf[len-1] = '\0';
 	
 	greeter_item_pam_set_user (buf);
-	greeter_item_ulist_enable ();
 	printf ("%c\n", STX);
 	fflush (stdout);
 	break;
@@ -541,6 +540,8 @@ greeter_ctrl_handler (GIOChannel *source,
 	printf ("%c\n", STX);
 	fflush (stdout);
 	greeter_ignore_buttons (FALSE);
+	greeter_item_ulist_enable ();
+
 	break;
 
     case GDM_QUIT:
@@ -1504,6 +1505,9 @@ main (int argc, char *argv[])
   gtk_window_move (GTK_WINDOW (window), gdm_wm_screen.x, gdm_wm_screen.y);
   gtk_widget_show_now (window);
 
+  greeter_item_ulist_unset_selected_user ();
+  greeter_item_ulist_enable ();
+
   /* can it ever happen that it'd be NULL here ??? */
   if G_UNLIKELY (window->window != NULL)
     {
