@@ -60,7 +60,7 @@ bin_exists (const char *command)
 static void
 query_greeter_restart_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to restart the machine?"),
+	if (gdm_common_query (_("Are you sure you want to restart the computer?"),
 			   FALSE /* markup */, _("_Reboot"), NULL,
 			   TRUE) == GTK_RESPONSE_YES) {
 		closelog();
@@ -73,7 +73,7 @@ query_greeter_restart_handler (void)
 static void
 query_greeter_halt_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to shut down the machine?"),
+	if (gdm_common_query (_("Are you sure you want to shut down the computer?"),
 			   FALSE /* markup */, _("Shut _Down"), NULL,
 			   TRUE) == GTK_RESPONSE_YES) {
 		closelog();
@@ -85,7 +85,7 @@ query_greeter_halt_handler (void)
 static void
 query_greeter_suspend_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to suspend the machine?"),
+	if (gdm_common_query (_("Are you sure you want to suspend the computer?"),
 			   FALSE /* markup */, _("_Suspend"), NULL,
 			   TRUE) == GTK_RESPONSE_YES) {
 		/* suspend interruption */
@@ -119,6 +119,11 @@ greeter_suspend_handler (void)
 static void
 greeter_config_handler (void)
 {
+        greeter_item_ulist_disable ();
+
+        /* Make sure to unselect the user */
+        greeter_item_ulist_unset_selected_user ();
+
 	/* we should be now fine for focusing new windows */
 	gdm_wm_focus_new_windows (TRUE);
 
@@ -158,7 +163,7 @@ greeter_system_append_system_menu (GtkWidget *menu)
 		gtk_tooltips_set_tip (tooltips, GTK_WIDGET (w),
 				      _("Run an XDMCP chooser which will allow "
 					"you to log into available remote "
-					"machines, if there are any."),
+					"computers, if there are any."),
 				      NULL);
 	}
 
@@ -317,6 +322,9 @@ greeter_system_handler (GreeterItemInfo *info,
 	  restart_radio = gtk_radio_button_new_with_mnemonic (radio_group,
 							     _("_Reboot the computer"));
 	  group_radio = restart_radio;
+	  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (restart_radio),
+				_("Reboot your computer"),
+				NULL);
 	  g_signal_connect(G_OBJECT(restart_radio), "button_press_event",
 			   G_CALLBACK(radio_button_press_event), NULL);
 	  gtk_box_pack_start (GTK_BOX (vbox),
@@ -331,6 +339,9 @@ greeter_system_handler (GreeterItemInfo *info,
 	  suspend_radio = gtk_radio_button_new_with_mnemonic (radio_group,
 							      _("Sus_pend the computer"));
 	  group_radio = suspend_radio;
+	  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (suspend_radio),
+				_("Suspend your computer"),
+				NULL);
 	  g_signal_connect(G_OBJECT(suspend_radio), "button_press_event",
 			   G_CALLBACK(radio_button_press_event), NULL);
 	  gtk_box_pack_start (GTK_BOX (vbox),
@@ -348,7 +359,7 @@ greeter_system_handler (GreeterItemInfo *info,
 	  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (chooser_radio),
 				_("Run an XDMCP chooser which will allow "
 				  "you to log into available remote "
-				  "machines, if there are any."),
+				  "computers, if there are any."),
 				NULL);
 	  g_signal_connect(G_OBJECT(chooser_radio), "button_press_event",
 			   G_CALLBACK(radio_button_press_event), NULL);
